--- res/res_agi.c.orig	Wed Jun  1 12:25:45 2005
+++ res/res_agi.c	Thu Jun  2 11:26:56 2005
@@ -335,11 +335,32 @@ static int handle_waitfordigit(struct as
 {
 	int res;
 	int to;
-	if (argc != 4)
+	
+	if (argc < 4 || argc > 5)
 		return RESULT_SHOWUSAGE;
 	if (sscanf(argv[3], "%i", &to) != 1)
 		return RESULT_SHOWUSAGE;
-	res = ast_waitfordigit_full(chan, to, agi->audio, agi->ctrl);
+	if (argc == 5) {
+		char *prompt = argv[4];
+		res = ast_streamfile(chan, prompt, chan->language);
+		if (res < 0)
+			return RESULT_FAILURE;
+		if (chan->stream)
+		{
+			res = ast_waitstream_full(chan, AST_DIGIT_ANY, agi->audio, agi->ctrl);
+			ast_stopstream(chan);
+			usleep(1000);
+			if (!res)
+				res = ast_waitfordigit_full(chan, to, agi->audio, agi->ctrl);
+		}
+		else {
+			res = ast_waitfordigit_full(chan, to, agi->audio, agi->ctrl);
+		}
+	}
+	else
+	{
+		res = ast_waitfordigit_full(chan, to, agi->audio, agi->ctrl);
+	}
 	fdprintf(agi->fd, "200 result=%d\n", res);
 	if (res >= 0)
 		return RESULT_SUCCESS;
@@ -1124,11 +1145,12 @@ static char usage_answer[] = 
 " channel failure, or 0 if successful.\n";
 
 static char usage_waitfordigit[] = 
-" Usage: WAIT FOR DIGIT <timeout>\n"
+" Usage: WAIT FOR DIGIT <timeout> [file to be streamed]\n"
 "        Waits up to 'timeout' milliseconds for channel to receive a DTMF digit.\n"
 " Returns -1 on channel failure, 0 if no digit is received in the timeout, or\n"
 " the numerical value of the ascii of the digit if one is received.  Use -1\n"
-" for the timeout value if you desire the call to block indefinitely.\n";
+" for the timeout value if you desire the call to block indefinitely.\n"
+" Second parameter is optional prompt that would play while waiting.";
 
 static char usage_sendtext[] =
 " Usage: SEND TEXT \"<text to send>\"\n"
